@@ -7,8 +7,6 @@ import tarfile
 import uuid
 import zipfile
 
-from collections import OrderedDict
-
 from .. import BaseProvider
 
 localized = True
@@ -298,7 +296,12 @@ class Provider(BaseProvider):
         The ``header`` argument expects a list or a tuple of strings that will serve as the header row
         if supplied. The ``data_columns`` argument expects a list or a tuple of string tokens, and these
         string tokens will be passed to  :meth:`pystr_format() <faker.providers.python.Provider.pystr_format>`
-        for data generation. Both ``header`` and ``data_columns`` myst be of the same length.
+        for data generation. Argument Groups are used to pass arguments to the provider methods.
+        Both ``header`` and ``data_columns`` must be of the same length.
+
+        Example:
+            fake.set_arguments('top_half', {'min_value': 50, 'max_value': 100})
+            fake.dsv(data_columns=('{{ name }}', '{{ pyint:top_half }}'))
 
         The ``num_rows`` argument controls how many rows of data to generate, and the ``include_row_ids``
         argument may be set to ``True`` to include a sequential row ID column.
@@ -385,24 +388,37 @@ class Provider(BaseProvider):
         )
 
     def json(self,
-             data_columns: list = [('name', 'name'), ('residency', 'address')],
+             data_columns: list = None,
              num_rows: int = 10,
              indent: int = None) -> str:
         """
-        Generate random JSON structured key/values
+        Generate random JSON structure values.
 
-        Using a list of records that is passed as ``data_columns``, you define the structure that
-        will be generated. Parameters are provider specific, and should be a dictionary that will
-        be passed to the provider method.
+        Using a dictionary or list of records that is passed as ``data_columns``,
+        define the structure that is used to build JSON structures.  For complex
+        data structures it is recommended to use the dictionary format.
 
-        Data Columns format
-            [('field_name', 'provider_name', {'parameters'})]
+        Data Column Dictionary format:
+            {'key name': 'definition'}}
 
-        The provider_name can also be a list of records, to create a list within the JSON data.
-        For value only entries within the list, set the 'field_name' to None.
+        The definition can simply be the 'name:argument_group' of a provider
+        method, or can also be string {{ tokens }} that are passed to python
+        provider pystr_format() method for complex string generation.
+        Argument Groups are used to pass arguments to the provider methods.
 
-        :param spec: specification for the data structure
-        :type data_columns: list
+        Example:
+            fake.set_arguments('top_half', {'min_value': 50, 'max_value': 100})
+            fake.json(data_columns={'Name': 'name', 'Score': 'pyint:top_half'})
+
+        Data Column List format:
+            [('key name', 'definition', {'arguments'})]
+
+        With the list format the definition can be a list of records, to create
+        a list within the structure data.  For literal entries within the list,
+        set the 'field_name' to None.
+
+        :param data_columns: specification for the data structure
+        :type data_columns: dict
         :param num_rows: number of rows the returned
         :type num_rows: int
         :param indent: number of spaces to indent the fields
@@ -410,50 +426,99 @@ class Provider(BaseProvider):
         :return: Serialized JSON data
         :rtype: str
 
-        :sample: data_columns=[('id', 'pyint', {'max_value': 20})], num_rows=3
-        :sample: data_columns=[('id', 'pyint'), ('details', (('name', 'name'),))], num_rows=1
-        :sample: data_columns=[('id', 'pyint'), ('details', [(None, 'name'), (None, 'name')])], num_rows=1
-        :sample: data_columns=[('id', 'pyint'), ('details', [('name', 'name'), ('name', 'name')])], num_rows=1
+        :sample: data_columns={'ID': 'pyint', 'Details': {'Name': 'name',
+                'Address': 'address'}}, num_rows=1
+        :sample: data_columns={'Candidates': ['name', 'name', 'name']},
+                num_rows=1
+        :sample: data_columns=[('Name', 'name'), ('Points', 'pyint',
+                {'min_value': 50, 'max_value': 100})], num_rows=1
         """
+        default_data_columns = {
+            'name': '{{name}}',
+            'residency': '{{address}}',
+        }
+        data_columns = data_columns if data_columns else default_data_columns
+
+        def process_list_structure(data: list) -> dict:
+            entry = {}
+
+            for name, definition, *arguments in data:
+                kwargs = arguments[0] if arguments else {}
 
-        def create_json_entry(data_columns: list) -> OrderedDict:
-            entry = OrderedDict()
-            for field_name, provider_name, *parameters in data_columns:
-                kwargs = parameters[0] if parameters else {}
                 if not isinstance(kwargs, dict):
-                    raise TypeError("Parameters must be a dictionary")
+                    raise TypeError('Invalid arguments type. Must be a dictionary')
 
-                if field_name is None:
-                    return self.generator.format(provider_name, **kwargs)
+                if name is None:
+                    return self._format_selection(definition, **kwargs)
 
-                if isinstance(provider_name, tuple):
-                    entry[field_name] = create_json_entry(provider_name)
-                elif isinstance(provider_name, list):
-                    entry[field_name] = [create_json_entry([item])
-                                         for item in provider_name]
+                if isinstance(definition, tuple):
+                    entry[name] = process_list_structure(definition)
+                elif isinstance(definition, (list, set)):
+                    entry[name] = [process_list_structure([item])
+                                   for item in definition]
                 else:
-                    entry[field_name] = self.generator.format(provider_name, **kwargs)
+                    entry[name] = self._format_selection(definition, **kwargs)
             return entry
 
-        if num_rows == 1:
-            return json.dumps(create_json_entry(data_columns), indent=indent)
+        def process_dict_structure(data: dict) -> dict:
+            entry = {}
 
-        data = [create_json_entry(data_columns) for _ in range(num_rows)]
+            if isinstance(data, str):
+                return self._format_selection(data)
+
+            if isinstance(data, (float, int)):
+                return data
+
+            for name, definition in data.items():
+                if isinstance(definition, (tuple, list)):
+                    entry[name] = [process_dict_structure(item)
+                                   for item in definition]
+                elif isinstance(definition, (dict, int, float)):
+                    entry[name] = process_dict_structure(definition)
+                else:
+                    entry[name] = self._format_selection(definition)
+
+            return entry
+
+        def create_json_structure(data_columns) -> dict:
+            if isinstance(data_columns, dict):
+                return process_dict_structure(data_columns)
+
+            if isinstance(data_columns, list):
+                return process_list_structure(data_columns)
+
+            raise TypeError('Invalid data_columns type. Must be a dictionary or list')
+
+        if num_rows == 1:
+            return json.dumps(create_json_structure(data_columns), indent=indent)
+
+        data = [create_json_structure(data_columns) for _ in range(num_rows)]
         return json.dumps(data, indent=indent)
 
     def fixed_width(self,
-                    data_columns: list = [(20, 'name'), (3, 'pyint', {'max_value': 20})],
+                    data_columns: list = None,
                     num_rows: int = 10,
                     align: str = 'left') -> str:
         """
         Generate random fixed width values.
 
-        Using a list of records that is passed as ``data_columns``, you define the structure that
-        will be generated. ``parameters`` are provider specific, and should be a dictionary that will
-        be passed to the provider method.
+        Using a list of tuple records that is passed as ``data_columns``, that
+        defines the structure that will be generated. Arguments within the
+        record are provider specific, and should be a dictionary that will be
+        passed to the provider method.
 
-        Data Columns format
-            [('field_width', 'provider_name', {'parameters'})]
+        Data Column List format
+            [('field width', 'definition', {'arguments'})]
+
+        The definition can simply be the 'name:argument_group' of a provider
+        method, or can also be string tokens that are passed to python
+        provider method pystr_format() for data generation.
+        Argument Groups can be used to pass arguments to the provider methods,
+        but will override the arguments supplied in the tuple record.
+
+        Example:
+            fake.set_arguments('top_half', {'min_value': 50, 'max_value': 100})
+            fake.fixed_width(data_columns=[(20, 'name'), (3, 'pyint:top_half')])
 
         :param data_columns: specification for the data structure
         :type data_columns: list
@@ -464,25 +529,48 @@ class Provider(BaseProvider):
         :return: Serialized Fixed Width data
         :rtype: str
 
-        :sample: align='right', data_columns=[(20, 'name'), (3, 'pyint', {'max_value': 20})], num_rows=3
+        :sample: data_columns=[(20, 'name'), (3, 'pyint', {'min_value': 50,
+                'max_value': 100})], align='right', num_rows=1
         """
+        default_data_columns = [
+            (20, 'name'),
+            (3, 'pyint', {'max_value': 20}),
+        ]
+        data_columns = data_columns if data_columns else default_data_columns
         align_map = {
             'left': '<',
             'middle': '^',
             'right': '>',
         }
-
         data = []
+
         for _ in range(num_rows):
             row = []
-            for field_width, provider_name, *parameters in data_columns:
-                kwargs = parameters[0] if parameters else {}
+
+            for width, definition, *arguments in data_columns:
+                kwargs = arguments[0] if arguments else {}
+
                 if not isinstance(kwargs, dict):
-                    raise TypeError("Parameters must be a dictionary")
+                    raise TypeError('Invalid arguments type. Must be a dictionary')
+
+                result = self._format_selection(definition, **kwargs)
+                field = "{0:%s%s}" % (align_map.get(align, '<'), width)
+                row.append(field.format(result)[:width])
 
-                result = self.generator.format(provider_name, **kwargs)
-                field = "{0:%s%s}" % (align_map.get(align, '<'), field_width)
-                row.append(field.format(result)[:field_width])
             data.append(''.join(row))
-
         return '\n'.join(data)
+
+    def _format_selection(self, definition, **kwargs):
+        """
+        Formats the string with PyStr Format if special characters are found.
+        """
+        if '{{' in definition and '}}' in definition:
+            return self.generator.pystr_format(definition)
+
+        if definition.count(':') == 1:
+            definition, argument_group = definition.split(':')
+            arguments = self.generator.get_arguments(argument_group.strip())
+
+            return self.generator.format(definition.strip(), **arguments)
+
+        return self.generator.format(definition, **kwargs)
